@@ -15,5 +15,5 @@ import sys
 from stestr.cli import main
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv[1:]))
