@@ -17,37 +17,37 @@ import os
 import sys
 
 
-if not os.path.isfile('.testr.conf'):
+if not os.path.isfile(".testr.conf"):
     sys.exit("Testr config file not found")
 
-with open('.testr.conf', 'r') as testr_conf_file:
+with open(".testr.conf", "r") as testr_conf_file:
     config = configparser.ConfigParser()
     config.readfp(testr_conf_file)
 
-    test_command = config.get('DEFAULT', 'test_command')
+    test_command = config.get("DEFAULT", "test_command")
     group_regex = None
-    if config.has_option('DEFAULT', 'group_regex'):
-        group_regex = config.get('DEFAULT', 'group_regex')
+    if config.has_option("DEFAULT", "group_regex"):
+        group_regex = config.get("DEFAULT", "group_regex")
 
 top_dir = None
 test_dir = None
-for line in test_command.split('\n'):
-    if 'subunit.run discover' in line:
-        command_parts = line.split(' ')
-        top_dir_present = '-t' in line
+for line in test_command.split("\n"):
+    if "subunit.run discover" in line:
+        command_parts = line.split(" ")
+        top_dir_present = "-t" in line
         for idx, val in enumerate(command_parts):
             if top_dir_present:
-                if val == '-t':
+                if val == "-t":
                     top_dir = command_parts[idx + 1]
                     test_dir = command_parts[idx + 2]
             else:
-                if val == 'discover':
+                if val == "discover":
                     test_dir = command_parts[idx + 1]
 
-with open('.stestr.conf', 'w') as stestr_conf_file:
-    stestr_conf_file.write('[DEFAULT]\n')
-    stestr_conf_file.write('test_path=%s\n' % test_dir)
+with open(".stestr.conf", "w") as stestr_conf_file:
+    stestr_conf_file.write("[DEFAULT]\n")
+    stestr_conf_file.write("test_path=%s\n" % test_dir)
     if top_dir:
-        stestr_conf_file.write('top_dir=%s\n' % top_dir)
+        stestr_conf_file.write("top_dir=%s\n" % top_dir)
     if group_regex:
-        stestr_conf_file.write('group_regex=%s\n' % group_regex)
+        stestr_conf_file.write("group_regex=%s\n" % group_regex)
